#!/bin/bash


#-------------------------
cmdName=MesAMDF
cmdVersion="1.0.0.0 2010-04-20"
#-------------------------

#-------------------------
cmdhelp()
{
echo ""
echo "$cmdName -input signal -output f0data -frameStep ms -f0hzmin min -f0hzmax max -median 3"
echo ""
} >/dev/stderr
#-------------------------

#-------------------------
error()
{
echo ""
echo "Syntax error : $errmsg"
cmdhelp

} >/dev/stderr


#-------------------------
# Arguments analysis
#-------------------------
lcmd=$@
minF0=55.0
maxF0=500.0
median=3
step=10.0
while test "X$1" != X
do
   case $1 in
   -in*)  input="$2" ; shift 2 ;;
   -out*) output="$2" ; shift 2 ;;
   -p|-frameStep) step=$2 ; shift 2 ;;
   -f0hzmin|-min) minF0=$2 ; shift 2 ;;
   -f0hzmax|-max) maxF0=$2 ; shift 2 ;;
   -median) median=$2 ; shift 2 ;;
   -help|-h|-sos|-aide) cmdhelp ; exit 0 ;;
   -*)         errmsg="Unknown Argument $1" ; error; exit 1 ;;
   esac
done

#-------------------------
# Input descriptor
#-------------------------
dsc_input=$input.dsc
if test  ! -f "$dsc_input"
then
  echo "Descriptor file $dsc_input non available" >/dev/stderr
  cmdhelp
  exit 1
fi

sampling=$(GetSamplingRateFromDesc < "$dsc_input")

#-------------------------
# JOB
#-------------------------

# PATH est configure ds bash_profile
{
# correction dcalage de trame
echo 0 0 |casnu f 

f0_amdf  -in $input -F $sampling -p $step -f0hzmin $minF0 -f0hzmax $maxF0  \
          | fmedian $median 
} > $output

#		  
#-------------------------
# Output descriptor
#-------------------------
fsize=$(stat -c%s "$output")
datacount=$(($fsize / 4))

{
echo "[CODING]"
echo "CODING_version="$cmdVersion
echo "[SETTINGS]"
echo "DATA_NAME=F0 AMDF"
echo "DATA_TYPE=temporal_serie"
echo "DATA_VAR_FORMAT=float_intel"
echo "ACRONYM='f0  '"
echo "DATA_COUNT="$datacount
echo "FRAME_SIZE="$size
echo "SAMPLING_PERIOD="$step
echo "[SCALE]"
echo "UNIT=Hz"
echo "[INFO]"
echo "SOURCE="$input
echo "CREATION_DATE="$(date)
echo "SOFTWARE="$cmdName $cmdVersion
echo "COPYRIGHT=Copyright  2010 - LPL"
echo "OPTIONS=-frameSizeMs "$size" -frameStepMs "$step
echo "COMMAND=" $cmdName $lcmd
} > $output.dsc


