#!/bin/bash


#-------------------------
cmdName=SignaixF0Autoc
cmdVersion="1.0.0.0 2010-04-20"
#-------------------------

#-------------------------
cmdhelp()
{
$PHONEDITPATH/plugins/DlgPrompt.exe "Syntax error : $errmsg"
echo ""
echo "$cmdName -F sampling(Hz) [-frameStepMs ms] [-n noiseLevel(dB)] [=]"
echo ""
}>/dev/stderr
#-------------------------

#-------------------------
error()
{
$PHONEDITPATH/plugins/DlgPrompt.exe "Syntax error : $errmsg"
echo ""
echo "Syntax error : $errmsg" 
cmdhelp

} >/dev/stderr
#-------------------------

#-------------------------
function resampling () 
{
input=$1
newS=$2
#step=
inputRS=$input'_RSautoc'		#cration d'un fichier inputRS qui sera utilis comme fichier input dans la suite du script

chemin=C:'/Program Files/phonedit/plugins'
"$chemin/"resampling.sh -input $input -output $inputRS -ns $newS
}

#-------------------------
# Arguments analysis
#-------------------------
lcmd=$@

seuil=-40
step=10.0

while test "X$1" != X
do
   case $1 in
    -in*)  input="$2" ; shift 2 ;;
   -out*) output="$2" ; shift 2 ;;
   -F|-sampling) sampling=$2 ; shift 2 ;;
   -p|-frameStepMs) step=$2 ; shift 2 ;;
   -f|-frameSizeMs) size=$2 ; shift 2 ;;
   -n| -noiseLevel) seuil=$2 ; shift 2 ;;
   -help|-h|-sos|-aide) cmdhelp ; exit 0 ;;
   -*)         errmsg="Unknown Argument $1" ; error; exit 1 ;;
   esac
done

#-------------------------
# Input descriptor
#-------------------------
dsc_input=$input.dsc
if test  ! -f "$dsc_input"
then
  echo "Descriptor file $dsc_input non available" >/dev/stderr
  cmdhelp
  exit 1
fi

sampling=$(GetParamFromDesc SAMPLING_RATE < "$dsc_input")


#-------------------------
# ReSampling
#-------------------------
inputRS=$input
#newS=$sampling

# La frquence d'chantillonnage doit tre gale  16000, sinon on rchantillonne
if [ $sampling != 16000 ]
then
resampling $input 16000
fi


#-------------------------
# JOB
#-------------------------

cat $inputRS | f0_autoc	-F 16000 -s $seuil -p $step > $output
	
#f0_autoc	-F 16000 -p $step -s $seuil  < $inputRS > $output 

#-------------------------
# Output descriptor
#-------------------------
fsize=$(stat -c%s "$output")
datacount=$(( $fsize / 4))
NChannels=$(GetParamFromDesc SRC_NCHANNELS < "$dsc_input")
BitSampleSize=$(GetParamFromDesc SRC_BITSPERSAMPLE < "$dsc_input")

{
echo "[CODING]"
echo "CODING_version="$cmdVersion
echo "[SETTINGS]"
echo "DATA_NAME=F0 Autocorrelation"
echo "DATA_TYPE=temporal_serie"
echo "DATA_VAR_FORMAT=float_intel"
echo "ACRONYM='f0  '"
echo "DATA_COUNT="$datacount
echo "FRAME_SIZE="$size
echo "SAMPLING_PERIOD="$step
#echo "SAMPLING_RATE="$newS
echo "[SCALE]"
echo "UNIT=Hz"
echo "[INFO]"
echo "SOURCE="$input
echo "SRC_RATE="$sampling
echo "SRC_BITSPERSAMPLE="$BitSampleSize
echo "SRC_NCHANNELS="$NChannels
echo "CREATION_DATE="$(date)
echo "SOFTWARE="$cmdName $cmdVersion
echo "COPYRIGHT=Copyright  2010 - LPL"
echo "OPTIONS=-frameSizeMs "$size" -frameStepMs "$step
echo "COMMAND=" $cmdName $lcmd
} > $output.dsc
