#!/bin/bash


#-------------------------
cmdName=SignaixVart
cmdVersion="1.0.0.0 2010-04-20"
#-------------------------

#-------------------------
cmdhelp()
{
echo ""
$PHONEDITPATH/plugins/DlgPrompt.exe "$cmdName -input infile -output outfile -F sampling  -k coef_variation"
echo "$cmdName -input infile -output outfile -F sampling  -k coef_variation"
echo ""
} >/dev/stderr
#-------------------------

#-------------------------
error()
{
$PHONEDITPATH/plugins/DlgPrompt.exe "Syntax error : $errmsg"
echo ""
echo "Syntax error : $errmsg"
cmdhelp

} >/dev/stderr


#-------------------------
# Arguments analysis
#-------------------------
lcmd=$@
step=10.0
sampling=20000
coef=0.5
while test "X$1" != X
do
   case $1 in
   -in*)  input="$2" ; shift 2 ;;
   -out*) output="$2" ; shift 2 ;;
   -frameSizeMs) frameSize=$2; shift 2;;
   -frameStepMs) step=$2; shift 2;;
   -F|-sampling) sampling=$2 ; shift 2 ;;
   -k) coef=$2 ; shift 2 ;;
   -help|-h|-sos|-aide) cmdhelp ; exit 0 ;;
   -*)         errmsg="Unknown Argument $1" ; error; exit 1 ;;
   esac
done

#-------------------------
# Input descriptor
#-------------------------
dsc_input=$input.dsc
if test  ! -f "$dsc_input"
then
  $PHONEDITPATH/plugins/DlgPrompt.exe "Descriptor file $dsc_input non available"
  echo "Descriptor file $dsc_input non available" >/dev/stderr
  cmdhelp
  exit 1
fi

src_sampling=$(GetParamFromDesc SAMPLING_RATE < "$dsc_input")

#-------------------------
# JOB
#-------------------------

# PATH est configure ds bash_profile

cat $input | vart F$sampling $coef > $output

#
#-------------------------
# Output descriptor
#-------------------------
fsize=$(stat -c%s "$output")
datacount=$(($fsize / 2))
NChannels=$(GetParamFromDesc SRC_NCHANNELS < "$dsc_input")
BitSampleSize=$(GetParamFromDesc SRC_BITSPERSAMPLE < "$dsc_input")

{
echo "[CODING]"
echo "CODING_version="$cmdVersion
echo "[SETTINGS]"
echo "DATA_NAME=Vart"
echo "DATA_TYPE=temporal_serie"
echo "DATA_VAR_FORMAT=int16_intel"
echo "ACRONYM='wave '"
echo "DATA_COUNT="$datacount
echo "FRAME_SIZE="$size
echo "SAMPLING_RATE="$src_sampling
echo "[SCALE]"
echo "H_UNIT=ms"
echo "V_UNIT="
echo "FLOAT_VALUE_AT_MAX=1.0"
echo "SIGNAL_DYNAMIC=32767.0"
echo "SIGNAL_ZERO=0"
echo "[INFO]"
echo "SOURCE="$input
echo "SRC_RATE="$src_sampling
echo "SRC_BITSPERSAMPLE="$BitSampleSize
echo "SRC_NCHANNELS="$NChannels
echo "CREATION_DATE="$(date)
echo "SOFTWARE="$cmdName $cmdVersion
echo "COPYRIGHT=Copyright  2010 - LPL"
echo "OPTIONS=-frameSizeMs "$size" -frameStepMs "$step
echo "COMMAND=" $cmdName $lcmd
} > $output.dsc


