#!/bin/bash


#-------------------------
cmdName=SignaixZCR
cmdVersion="1.0.0.1 2010-08-19"
# 1.0.0.0 2010-04-20 : created by Loise Dumas
# 1.0.0.1 2010-08-19 : AG replace options : -F by -Fs  ; -U by -unit ; -f by -frameSize ; -p by -frameStep
#-------------------------

#-------------------------
cmdhelp()
{
echo ""
$PHONEDITPATH/plugins/DlgPrompt.exe "$cmdName -input infile -output outfile -Fs fech [-unit ec|ms] [-frameSize size] [-frameStep step]"
echo "$cmdName -input infile -output outfile -Fs samplingRate [-unit ec|ms] [-frameSize size] [-frameStep step]"
echo ""
} >/dev/stderr
#-------------------------

#-------------------------
error()
{
$PHONEDITPATH/plugins/DlgPrompt.exe "Syntax error : $errmsg"
echo ""
echo "Syntax error : $errmsg"
cmdhelp

} >/dev/stderr


#-------------------------
# Arguments analysis
#-------------------------
lcmd=$@
format='ms'
framesize=10.0
framestep=10.0
while test "X$1" != X
do
   case $1 in
   -in*)  input="$2" ; shift 2 ;;
   -out*) output="$2" ; shift 2 ;;
   -F|-Fs) sampling=$2 ; shift 2 ;;
   -U|-unit) format=$2 ; shift 2 ;;
#   -U) case $2 in
#		ec) format=ec; shift 2 ;;
#		ms) format=ms; shift 2 ;;
#		*) errmsg="-U ec|ms" ; error; exit 1 ;;
   -f|-frameSize) frameSize=$2 ; shift 2 ;;
   -p|-frameStep) framestep=$2 ; shift 2 ;;
   -help|-h|-sos|-aide) cmdhelp ; exit 0 ;;
   -*)         errmsg="Unknown Argument $1" ; error; exit 1 ;;
   esac
done

#-------------------------
# Input descriptor
#-------------------------
dsc_input=$input.dsc
if test  ! -f "$dsc_input"
then
  echo "Descriptor file $dsc_input non available" >/dev/stderr
  cmdhelp
  exit 1
fi

sampling=$(GetParamFromDesc SAMPLING_RATE < "$dsc_input")

#-------------------------
# JOB
#-------------------------

# PATH est configure ds bash_profile

tpz -F $sampling -U $format -f $framesize -p $framestep < $input > $output

#		  
#-------------------------
# Output descriptor
#-------------------------
fsize=$(stat -c%s "$output")
datacount=$(($fsize / 4))
NChannels=$(GetParamFromDesc SRC_NCHANNELS < "$dsc_input")
BitSampleSize=$(GetParamFromDesc SRC_BITSPERSAMPLE < "$dsc_input")

{
echo "[CODING]"
echo "CODING_version="$cmdVersion
echo "[SETTINGS]"
echo "DATA_NAME=TPZ"
echo "DATA_TYPE=temporal_serie"
echo "DATA_VAR_FORMAT=float_intel"
echo "ACRONYM='f0  '"
echo "DATA_COUNT="$datacount
echo "FRAME_SIZE="$size
echo "SAMPLING_PERIOD="$framestep
echo "[SCALE]"
echo "UNIT=Hz"
echo "[INFO]"
echo "SOURCE="$input
echo "SRC_RATE="$sampling
echo "SRC_BITSPERSAMPLE="$BitSampleSize
echo "SRC_NCHANNELS="$NChannels
echo "CREATION_DATE="$(date)
echo "SOFTWARE="$cmdName $cmdVersion
echo "COPYRIGHT=Copyright  2010 - LPL"
echo "OPTIONS=-Fs "$fech" -U "$format" -frameSize "$frameSize" -frameStep "$framestep
echo "COMMAND=" $cmdName $lcmd
} > $output.dsc


