#!/bin/bash


#-------------------------
cmdName=resampling.sh
cmdVersion="1.0.0.1 2010-08-20"
#1.0.0.0 2010-04-20  : created by Loise Dumas
#1.0.0.1 2010-08-20 : add arguments + messages by AG
#-------------------------

#-------------------------
cmdhelp()
{
echo ""
echo "$cmdName -input inputRawSignal -output outputRawSignal -newSampling newSamplingFrequency"
echo ""
} >/dev/stderr
#-------------------------

#-------------------------
error()
{
echo ""
echo $cmdName : "$errmsg"
$PHONEDITPATH/plugins/DlgPrompt.exe $errmsg -title $cmdName
cmdhelp

} >/dev/stderr


#-------------------------
# Arguments analysis
#-------------------------
lcmd=$@
step=10
while test "X$1" != X
do
   case $1 in
   -in*)  input="$2" ; shift 2 ;;
   -out*) output="$2" ; shift 2 ;;
   -p|-ns|-newSampling) newSampling=$2 ; shift 2 ;;
   -help|-h|-sos|-aide) cmdhelp ; exit 0 ;;
   -*)         errmsg="Unknown Argument $1" ; error; exit 1 ;;
   esac
done

#-------------------------
# Input  ?
#-------------------------
if test  ! -f "$input"  # -f :  True if file is a regular File.
then
  errmsg="Input file '$input' non available" ; error ; #echo "Input file '$input' non available" >/dev/stderr
  exit 1
fi

#-------------------------
# Input descriptor ?
#-------------------------
dsc_input=$input.dsc
if test  ! -f "$dsc_input"
then
  errmsg="Descriptor file '$dsc_input' non available" ; error ;#echo "Descriptor file $dsc_input non available" >/dev/stderr
  exit 1
fi

#-------------------------
# output  ?
#-------------------------
if test -z "$output"
then
  errmsg="Output file undefined" ; error ;# echo "Output file undefined" >/dev/stderr
  exit 1
fi

#-------------------------
# output  sampling rate ?
#-------------------------
if test -z "$newSampling"
then
  errmsg="New Sampling Frequency undefined" ; error ;
  exit 1
fi

#-------------------------
# signal format
#-------------------------
sampling=$(GetParamFromDesc SAMPLING_RATE < "$dsc_input")
BitSampleSize=$(GetParamFromDesc SRC_BITSPERSAMPLE < "$dsc_input")
sampleSize=$(($BitSampleSize / 8))
if test $sampleSize != 2
then
  errmsg="Only on 16-bit samples" ; error ;
  exit 1
fi

#-------------------------
# JOB
#-------------------------
errmsg=$( {
sox -t raw -s -w -r $sampling $input -t raw -s -r $newSampling $output polyphase


#		  
#-------------------------
# Output descriptor
#-------------------------
fsize=$(stat -c%s "$output")
datacount=$(($fsize / 2))
NChannels=$(GetParamFromDesc SRC_NCHANNELS < "$dsc_input")

} 2>&1 )

if test ! -z "$errmsg"
then
  error ;
  exit 1
fi


{
echo "[CODING]"
echo "CODING_version="$cmdVersion
echo "[SETTINGS]"
echo "DATA_NAME=Waveform"
echo "DATA_TYPE=temporal_serie"
echo "DATA_VAR_FORMAT=int16_intel"
echo "ACRONYM='wave'"
echo "DATA_COUNT="$datacount
echo "FRAME_SIZE="$size
#echo "SAMPLING_PERIODE="
echo "SAMPLING_RATE="$newSampling
echo "[SCALE]"
echo "H_UNIT=ms"
echo "V_UNIT="
echo "FLOAT_VALUE_AT_MAX=1.000"
echo "SIGNAL_DYNAMIC=32767.000"
echo "SIGNAL_ZERO=0"
echo "[INFO]"
echo "SOURCE="$input
echo "SRC_RATE="$sampling
echo "SRC_BITSPERSAMPLE="$BitSampleSize
echo "SRC_NCHANNELS="$NChannels
echo "CREATION_DATE="$(date)
echo "SOFTWARE="$cmdName $cmdVersion
echo "COPYRIGHT=Copyright  2010 - LPL"
echo "OPTIONS=-newSample "$newSampling
echo "COMMAND=" $cmdName $lcmd
} > $output.dsc


